import setuptools
setuptools.setup(
    name='python_colorful_font_output',
    version='0.0.8',
    author='Yuli Wang',
    author_email='winterland_yuli2@163.com',
    description='This is a library to make your terminal more beautiful! ',
    long_description='0.0.7 has a BUG. This package is the after Debug module. Please install the library and run (class)Help.ask_the_module_questions() or Help.the_pc_information(), it will tell you all of the module.',
    long_descripition_content_type="text/markdown",
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)